@@ -1,3 +1,4 @@
+from enum import Enum
 import logging
 import time
 import base64
@@ -45,6 +46,13 @@ TRANSFORM_PROD_API = "https://api.transformdata.io"
 logger = logging.getLogger(__name__)
 
 
+class DWValidationType(Enum):  # noqa: D
+    ALL = "allIssues"
+    DATA_SOURCE = "dataSourceIssues"
+    DIMENSION = "dimensionIssues"
+    METRIC = "metricIssues"
+
+
 class BaseInterface:
     """Base implementation for our various GraphQL APIs we connect to.
 
@@ -121,7 +129,7 @@ class BackendInterface(BaseInterface):  # noqa: D
         """Finds and validates yaml configs in the provided directory"""
         repo, branch, commit = resolve_local_commit_info(config_dir)
         try:
-            model = tt_validate_configs(
+            response = tt_validate_configs(
                 auth_header=self.auth_header,
                 repo=repo,
                 branch=branch,
@@ -129,7 +137,7 @@ class BackendInterface(BaseInterface):  # noqa: D
                 config_dir=config_dir,
                 api_url=self.rest_api_url,
             )
-            return model
+            return ModelKey.from_snake_dict(response.json()["model"])
         except Exception as e:
             error_content = str(e).split(ERROR_RESPONSE_PREFIX)
             error_msg = str(e)
@@ -763,15 +771,17 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["dimensions"]
         ]
 
-    def get_all_data_warehouse_validation_issues(self, model_key: Optional[ModelKey] = None) -> List[str]:
-        """Get a list of all data warehouse validation issues"""
+    def get_data_warehouse_validation_issues(
+        self, dw_validation_type: DWValidationType, model_key: Optional[ModelKey] = None
+    ) -> List[str]:
+        """Get data warehouse validation issues associated with the dw_validation_type for the model"""
         query = gql(
-            """
-            query ValidateModel($modelKey: ModelKeyInput) {
-                validations(modelKey: $modelKey) {
-                    allIssues
-                }
-            }
+            f"""
+            query ValidateModel{dw_validation_type.name}($modelKey: ModelKeyInput) {{
+                validations(modelKey: $modelKey) {{
+                    {dw_validation_type.value}
+                }}
+            }}
             """
         )
 
@@ -788,7 +798,7 @@ class MQLInterface(BaseInterface):  # noqa: D
                 if model_key
                 else None
             },
-        )["validations"]["allIssues"]
+        )["validations"][dw_validation_type.value]
 
     def create_query(  # noqa: D
         self,
